
API reference
+++++++++++++++++++++++++++++

Classes
===============

.. autosummary::
   :toctree: generated

   pypago.sections.Section
   pypago.sections.GridSection

Processing model grid
=======================

.. autosummary::
   :toctree: generated

   pypago.coords.create_coord
   pypago.grid.create_grid
   pypago.sections.extract_grid_sections


Input/Output
=======================

.. autosummary::
   :toctree: generated

    pypago.pyio.save
    pypago.pyio.load
    pypago.pyio.read_time

NetCDF conversion
=======================

.. autosummary::
   :toctree: generated

   pypago.nc

Loading data
=======================

.. autosummary::
   :toctree: generated

    pypago.data.loaddata_sec_t
    pypago.data.loaddata_sec_uv
    pypago.data.loaddata_sec_uv_roms
    pypago.data.loaddata_area_t

Miscellaneous
===================

.. autosummary::
   :toctree: generated

   pypago.misc.findsecnum
   pypago.misc.finddomnum


Scientific calculations
============================

.. autosummary::
   :toctree: generated

    pypago.secdiag
    pypago.areadiag

Plotting
============================
.. autosummary::
   :toctree: generated

   pypago.plot.plot_dom_mask 
   pypago.plot.pcolplot
   pypago.plot.contourplot
